#' Add .gitignore file suitable for R project
#'
#' @inheritParams create_fairify
#' @param url URL of a `.gitignore` template file
#' @param additional_patterns Patterns to add to the `.gitignore` file
#'
#' @return `NULL`, this function is used for side effect.
#' @export
#'
#' @examples
#' path <- tempdir()
#' add_gitignore(path = path)
#' readLines(file.path(path, ".gitignore"))
add_gitignore <- function(path = ".",
                          url = "https://raw.githubusercontent.com/github/gitignore/main/R.gitignore",
                          additional_patterns = c("/public")) {
  destfile = file.path(path, ".gitignore")
  stopifnot(download.file(url, destfile) == 0)
  s <- readLines(destfile)
  s <- c(add_comment_block(".gitignore template from:",
                           url,
                           paste("Downloaded the", Sys.time())),
         s,
         add_comment_block("Specific files for fairify"),
         additional_patterns)
  writeLines(s, destfile)
}

add_comment <- function(x, comment_tag = "#") {
  paste(comment_tag, x)
}

add_comment_block <- function(..., comment_tag = "#", line_len) {
  x <- list(...)
  c("",
    strrep(comment_tag, 80),
    sapply(x, add_comment, comment_tag = comment_tag),
    strrep(comment_tag, 80),
    "")
}
